=========
breizorro
=========
|Pypi Version|
|Python Versions|
|Project License|

A tool for creating a binary mask given a FITS image

==============
Installation
==============

Installation from source_,
working directory where source is checked out

.. code-block:: bash
  
    $ pip install .

This package is available on *PYPI*, allowing

.. code-block:: bash
  
    $ pip install breizorro

To show help message and exit

.. code-block:: bash
   
   $ breizorro --help

=============
Documentation
=============

Documentation is available on the GitHub page_.

=======
License
=======

This project is licensed under the GNU General Public License v3.0 - see license_ for details.

=============
Contribute
=============

Contributions are always welcome! Please ensure that you adhere to our coding
standards pep8_.

.. |Project License| image:: https://img.shields.io/badge/license-GPL-blue.svg
                     :target: https://github.com/ratt-ru/breizorro/blob/main/LICENSE
                     :alt:

.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/breizorro.svg
                     :target: https://pypi.python.org/pypi/breizorro/
                     :alt:

.. |Pypi Version| image:: https://img.shields.io/pypi/v/breizorro.svg
                  :target: https://pypi.python.org/pypi/breizorro
                  :alt:

.. _source: https://github.com/ratt-ru/breizorro
.. _license: https://github.com/ratt-ru/breizorro/blob/main/LICENSE
.. _pep8: https://www.python.org/dev/peps/pep-0008
.. _page: https://ratt-ru.github.io/breizorro
